@@ -29,7 +29,7 @@
 *
 * Version Creation Date:   12/30/03
 *
-* $Revision: 1.111 $
+* $Revision: 1.119 $
 *
 * File Description:  New GenBank flatfile generator, internal header
 *
@@ -138,6 +138,7 @@ typedef struct int_asn2gb_job {
   Boolean         masterStyle;
   Boolean         newSourceOrg;
   Boolean         produceInsdSeq;
+  Boolean         oldXmlPolicy;
   Boolean         refseqConventions;
   ValNodePtr      lockedBspList;
   ValNodePtr      gapvnp;
@@ -157,6 +158,7 @@ typedef struct int_asn2gb_job {
   Boolean         www;
   Boolean         specialGapFormat;
   Boolean         hideGoTerms;
+  Boolean         multiIntervalGenes;
   Boolean         reindex;
   Int4            seqGapCurrLen;
   ValNodePtr      gihead;
@@ -600,6 +602,7 @@ NLM_EXTERN SourceType orgModToSourceIdx [41];
 typedef enum {
   FTQUAL_allele = 1,
   FTQUAL_anticodon,
+  FTQUAL_artificial_location,
   FTQUAL_bond,
   FTQUAL_bond_type,
   FTQUAL_bound_moiety,
@@ -718,6 +721,7 @@ typedef enum {
   FTQUAL_trna_aa,
   FTQUAL_trna_codons,
   FTQUAL_trna_codons_note,
+  FTQUAL_UniProtKB_evidence,
   FTQUAL_usedin,
   FTQUAL_xtra_prod_quals,
   ASN2GNBK_TOTAL_FEATUR
@@ -1017,7 +1021,8 @@ NLM_EXTERN CharPtr FFFlatLoc (
   IntAsn2gbJobPtr ajp,
   BioseqPtr bsp,
   SeqLocPtr location,
-  Boolean masterStyle
+  Boolean masterStyle,
+  Boolean isGap
 );
 
 NLM_EXTERN void FF_www_featloc(StringItemPtr ffstring, CharPtr loc);
@@ -1130,6 +1135,7 @@ NLM_EXTERN void AddFeatureBlock (
 NLM_EXTERN void AddLocusBlock (
   Asn2gbWorkPtr awp,
   Boolean willshowwgs,
+  Boolean willshowcage,
   Boolean willshowgenome,
   Boolean willshowcontig,
   Boolean willshowsequence
@@ -1181,6 +1187,9 @@ NLM_EXTERN void AddSourceFeatBlock (
 NLM_EXTERN void AddWGSBlock (
   Asn2gbWorkPtr awp
 );
+NLM_EXTERN void AddCAGEBlock (
+  Asn2gbWorkPtr awp
+);
 NLM_EXTERN void AddGenomeBlock (
   Asn2gbWorkPtr awp
 );
